All of lore.kernel.org
 help / color / mirror / Atom feed
* [LTP] [PATCH] proc/proc01.c: ignore stable_secret files
@ 2015-07-08 20:33 Jeffrey Bastian
  2015-07-09  7:51 ` Jan Stancek
  0 siblings, 1 reply; 5+ messages in thread
From: Jeffrey Bastian @ 2015-07-08 20:33 UTC (permalink / raw)
  To: ltp-list

Linux 4.1.0 introduced a per-NIC IPv6 stable_secret file for RFC7217.
The stable_secret file for each NIC cannot be read until it is set,
thus LTP fails like this:

proc01      1  TFAIL  :  proc01.c:392: read failed: /proc/sys/net/ipv6/conf/all/stable_secret: errno=EIO(5): Input/output error
proc01      2  TFAIL  :  proc01.c:392: read failed: /proc/sys/net/ipv6/conf/default/stable_secret: errno=EIO(5): Input/output error
proc01      3  TFAIL  :  proc01.c:392: read failed: /proc/sys/net/ipv6/conf/eno1/stable_secret: errno=EIO(5): Input/output error
...

Ignore the stable_secret files in the proc01 test.

TODO: A future test should verify stable_secret functionality.
  ~]# cat /proc/sys/net/ipv6/conf/eno1/stable_secret
  cat: /proc/sys/net/ipv6/conf/eno1/stable_secret: Input/output error
  ~]# echo "ffff:ffff:ffff:ffff:ffff:ffff:255.255.255.255" > /proc/sys/net/ipv6/conf/eno1/stable_secret
  ~]# cat /proc/sys/net/ipv6/conf/eno1/stable_secret
  ffff:ffff:ffff:ffff:ffff:ffff:ffff:ffff

Signed-off-by: Jeffrey Bastian <jbastian@redhat.com>
---
 testcases/kernel/fs/proc/proc01.c | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/testcases/kernel/fs/proc/proc01.c b/testcases/kernel/fs/proc/proc01.c
index f513110eca0e..b9ff3ac42fe2 100644
--- a/testcases/kernel/fs/proc/proc01.c
+++ b/testcases/kernel/fs/proc/proc01.c
@@ -290,14 +290,15 @@ static long readproc(const char *obj)
 			     dir_ent != NULL;
 			     dir_ent = (struct dirent *)readdir(dir)) {
 
 				/* Ignore ".", "..", "kcore", and
 				 * "/proc/<pid>" (unless this is our
 				 * starting point as directed by the
 				 * user).
 				 */
 				if (strcmp(dir_ent->d_name, ".") &&
 				    strcmp(dir_ent->d_name, "..") &&
 				    strcmp(dir_ent->d_name, "kcore") &&
+				    strcmp(dir_ent->d_name, "stable_secret") &&
 				    (fnmatch("[0-9]*", dir_ent->d_name,
 					     FNM_PATHNAME) ||
 				     strcmp(obj, procpath))) {
@@ -290,14 +290,15 @@ static long readproc(const char *obj)
 			     dir_ent = (struct dirent *)readdir(dir)) {
 
-				/* Ignore ".", "..", "kcore", and
-				 * "/proc/<pid>" (unless this is our
+				/* Ignore ".", "..", "kcore", "stable_secret",
+                                 * and "/proc/<pid>" (unless this is our
 				 * starting point as directed by the
 				 * user).
-- 
1.9.4

------------------------------------------------------------------------------
Don't Limit Your Business. Reach for the Cloud.
GigeNET's Cloud Solutions provide you with the tools and support that
you need to offload your IT needs and focus on growing your business.
Configured For All Businesses. Start Your Cloud Today.
https://www.gigenetcloud.com/
_______________________________________________
Ltp-list mailing list
Ltp-list@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/ltp-list

^ permalink raw reply related	[flat|nested] 5+ messages in thread

end of thread, other threads:[~2015-07-09 15:49 UTC | newest]

Thread overview: 5+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2015-07-08 20:33 [LTP] [PATCH] proc/proc01.c: ignore stable_secret files Jeffrey Bastian
2015-07-09  7:51 ` Jan Stancek
2015-07-09 15:12   ` Jeffrey Bastian
2015-07-09 15:14   ` [LTP] [PATCH v2] " Jeffrey Bastian
2015-07-09 15:49     ` Jan Stancek

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.